@@ -8,6 +8,9 @@ import argparse
 import os
 import sys
 
+import httpx
+from selectolax.parser import HTMLParser
+
 from dom import __version__
 
 
@@ -18,6 +21,15 @@ def parse_args():
                                      description="A domonic-like wrapper around selectolax")
 
     parser.add_argument('-v', '--version', action='store_true')
+    parser.add_argument(
+    "-q",
+    "--querySelectorAll",
+    help="pass a url and a css query",
+    type=str,
+    nargs="*",
+    default=None,
+    )
+
     args = parser.parse_args()
     return args
 
@@ -28,6 +40,15 @@ def do_things(arguments):
         print(__version__)
         return __version__
 
+    if arguments.querySelectorAll is not None:
+        url, query = arguments.querySelectorAll
+        if 'http' not in url:
+            url = 'https://' + url
+        r = httpx.get(url)
+        doc = HTMLParser(r.text)
+        result = doc.css(query)
+        for n in result:
+            print(str(n.html))
 
 def run():
     """[Entry point required by setup.py console_scripts.]
